package com.fs.course.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.course.domain.FsUserWatchCourseStatistics;

import java.util.List;

/**
 * 会员看课统计-按课程统计Mapper接口
 *
 * @author fs
 * @date 2025-06-17
 */
public interface FsUserWatchCourseStatisticsMapper extends BaseMapper<FsUserWatchCourseStatistics>{
    /**
     * 查询会员看课统计-按课程统计
     *
     * @param id 会员看课统计-按课程统计主键
     * @return 会员看课统计-按课程统计
     */
    FsUserWatchCourseStatistics selectFsUserWatchCourseStatisticsById(Long id);

    /**
     * 查询会员看课统计-按课程统计列表
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 会员看课统计-按课程统计集合
     */
    List<FsUserWatchCourseStatistics> selectFsUserWatchCourseStatisticsList(FsUserWatchCourseStatistics fsUserWatchCourseStatistics);

    /**
     * 查询会员看课明细汇总
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 会员看课统计-按课程统计集合
     */
    List<FsUserWatchCourseStatistics> selectFsUserWatchCourseStatisticsListTotal(FsUserWatchCourseStatistics fsUserWatchCourseStatistics);

    /**
     * 新增会员看课统计-按课程统计
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 结果
     */
    int insertFsUserWatchCourseStatistics(FsUserWatchCourseStatistics fsUserWatchCourseStatistics);

    /**
     * 修改会员看课统计-按课程统计
     *
     * @param fsUserWatchCourseStatistics 会员看课统计-按课程统计
     * @return 结果
     */
    int updateFsUserWatchCourseStatistics(FsUserWatchCourseStatistics fsUserWatchCourseStatistics);

    /**
     * 删除会员看课统计-按课程统计
     *
     * @param id 会员看课统计-按课程统计主键
     * @return 结果
     */
    int deleteFsUserWatchCourseStatisticsById(Long id);

    /**
     * 批量删除会员看课统计-按课程统计
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsUserWatchCourseStatisticsByIds(Long[] ids);

    /**
     * 插入看课统计数据
     */
    void insertFsUserWatchCourseStatisticsTask(FsUserWatchCourseStatistics fsUserWatchCourseStatistics);
}
